TextInline class final

Plain text content.

TextInline is the most basic inline node, containing a string of text with no formatting.

Inheritance
Annotations
  • @immutable

Constructors

TextInline(String text, {NodeMeta? meta})
Creates a text node with the given content.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
meta NodeMeta?
Debug metadata (source location, attributes).
finalinherited
props List<Object?>
Semantic properties used for equality and hashing.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited